Crate bip322_rs

Crate bip322_rs 

Re-exports

pub use bitcoin;

Functions

create_message_signature_p2wpkh
Sign for segwit inputs
create_message_signature_taproot
Sign for taproot inputs
create_to_sign
Create the to_sign transaction.
create_to_spend
Create the to_spend transaction.
message_hash
Create the tagged message hash.
sign_full
Signs in the BIP-322 full format from proper Rust types and returns the full transaction.
sign_full_encoded
Signs the BIP-322 full from spec-compliant string encodings.
sign_simple
Signs in the BIP-322 simple format from proper Rust types and returns the witness.
sign_simple_encoded
Signs the BIP-322 simple from spec-compliant string encodings.
verify_full_encoded
Verifies the BIP-322 full from spec-compliant string encodings.
verify_full_witness
verify_simple
Verifies the BIP-322 simple from proper Rust types.
verify_simple_encoded
Verifies the BIP-322 simple from spec-compliant string encodings.